==> haskell-lsp-test0.14.0-0.14.0.2-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-5VvtJLWhaRRE4clZtnUNcJ
key:                  lsp-test-0.14.0.2-5VvtJLWhaRRE4clZtnUNcJ
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  2ac04b2bc102dc8539ff75187907a485
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-5VvtJLWhaRRE4clZtnUNcJ
depends:
    Diff-0.4.1-7DJ54PO7amxJCKVFCJguu4
    Glob-0.10.2-IttgZQd8QbwIoW4wWo8qwk
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    aeson-pretty-0.8.10-5TSYkD8Co5LLMI8e0zAoII
    ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
    async-2.2.5-A9yY3sStrUyIJcfOkNbDOv base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6olN0R4zhzQGfJxY5P1sQG
    conduit-parse-0.2.1.1-Jyqt3cC7u5UIhDPtL52e5i containers-0.6.5.1
    data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS directory-1.3.6.2
    filepath-1.4.2.2 lens-5.2.3-QYXO5VAAmZ55WrLxxHJc7
    lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 process-1.6.16.0
    some-1.0.5-L5glA67mR8RJufLDsA2lRz text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-KbuohGKDXjMH23185MHhrF

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test0.14.0-0.14.0.2-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-6KfOeVewah5G6dcM25UUW1
key:                  lsp-test-0.14.0.2-6KfOeVewah5G6dcM25UUW1
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  70150afec24edb05f15fb92d480c435f
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-6KfOeVewah5G6dcM25UUW1
depends:
    Diff-0.4.1-7DJ54PO7amxJCKVFCJguu4
    Glob-0.10.2-IttgZQd8QbwIoW4wWo8qwk
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    aeson-pretty-0.8.10-5TSYkD8Co5LLMI8e0zAoII
    ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
    async-2.2.5-A9yY3sStrUyIJcfOkNbDOv base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-FMkxkIELY206tJUNMQQAmY
    conduit-parse-0.2.1.1-7cLqqzj5Ef7G9tuWiW2A8M containers-0.6.5.1
    data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS directory-1.3.6.2
    filepath-1.4.2.2 lens-5.2.3-QYXO5VAAmZ55WrLxxHJc7
    lsp-types-1.4.0.1-8fq24p7hfveKkgUEYsAszh mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 process-1.6.16.0
    some-1.0.5-L5glA67mR8RJufLDsA2lRz text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-KbuohGKDXjMH23185MHhrF

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
